==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MSY_sys_func_help.h <==
/* $Date: 1997/11/12 13:18:07 $  $Author: tonner $  $Revision: 1.24 $ */

/**************************************************************************/
/* FILE:             MSY_sys_func_help.h                                  */
/* Autor:            Andreas Kemper , Oliver Kluge , Karsten Morisse      */
/* Erstellt:         24/06/91                                             */
/* Letzte Aenderung: 26/10/94                                             */
/**************************************************************************/

#ifndef __MSY_sys_func_help__
#define __MSY_sys_func_help__

#ifndef GRAPHIC
#  include "MCA_calc.h"
#endif /* GRAPHIC */

/*** Typedefinitionen *****************************************************/

#ifndef GRAPHIC
typedef GEN (PARI_FUNC )(GEN, GEN );
typedef GEN (PARI_FUNC1)(GEN, long);
typedef GEN (PARI_FUNC2)(GEN);
typedef int (PARI_FUNC3)(GEN);
#endif  /* GRAPHIC */

/**************************************************************************/
/* Deklaration der Systemfunktionen fuer deren Initialisierung.           */ 
/**************************************************************************/

/*** Prototypen zur Datei MSY_sys_func.c **********************************/

S_Pointer MSY_eval_null	( 	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_id ( 	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_contains (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_genident (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_indets (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_help (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_hold (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_last (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_history (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_ptime (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_rtime (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_time (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_append (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_print (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_input (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_textinput (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_text2expr (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_expr2text (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );


S_Pointer MSY_eval_level (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_eval (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_map (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_zip (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_select (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_split (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_has (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_sort (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_reset (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
void      MSY_eval_reset_intern ( VOID );

S_Pointer MSY_eval_memory (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_load (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_anames (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_stack_info (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec,
				long		 mode );
S_Pointer MSY_eval_float (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_bool (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_system (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_testargs (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_sysname (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_getpid  (    S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_bytes (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
/*
S_Pointer MSY_eval_random (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
*/
S_Pointer MSY_eval_ass_mem (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_val (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_traperror (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_error (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_nohistory (	S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_input_filter( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );

S_Pointer MSY_eval_igamma     ( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );

S_Pointer MSY_eval_isqrt      ( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );

#ifndef MACINTOSH

S_Pointer MSY_eval_register   ( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );

#endif


MUPbool MSY_indets ( S_Pointer s, S_Pointer *assmem, long type,
		     MUPbool enter, S_Pointer call );


/*** Prototypen zur Datei MSY_arith_func.c ********************************/

S_Pointer MSY_eval_trans_func (	S_Pointer	 root, 
				long		 prev_func, 
				long		 eval_type, 
				S_Pointer	 function );
S_Pointer MSY_eval_arith_func(	S_Pointer	 root, 
				long		 prev_func, 
				long		 eval_type, 
				S_Pointer	 function );
#ifndef GRAPHIC
S_Pointer MSY_arbitrary_args (	S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				PARI_FUNC	*func,
				S_Pointer	 exec );
#endif /*** GRAPHIC ***/
S_Pointer MSY_igcd (		S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_ilcm (		S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_igcdex (		S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_sign (		S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_max (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_min (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_powermod (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_ifactor (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_ithprime (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_phi (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_primedivisors( S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_numdivisors (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_pref        (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_sysorder    (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_block       (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_protected   (S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_bin_op      (S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );

S_Pointer MSY_eval_lllint      (S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );


#ifndef GRAPHIC
GEN MSY_fact	( GEN value );
GEN MSY_round	( GEN value );
GEN MSY_trunc	( GEN value );
#endif  /* GRAPHIC */


#endif /*__MSY_sys_func_help__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MSY_sys_func_help.h <==
/* $Date: 2000/02/28 12:08:38 $  $Author: tonner $  $Revision: 1.21 $ */

/**************************************************************************/
/* FILE:             MSY_sys_func_help.h                                  */
/* Autor:            Andreas Kemper , Oliver Kluge , Karsten Morisse      */
/* Erstellt:         24/06/91                                             */
/* Letzte Aenderung: 26/10/94                                             */
/**************************************************************************/

#ifndef __MSY_sys_func_help__
#define __MSY_sys_func_help__

#ifndef GRAPHIC
#  include "MCA_calc.h"
#endif /* GRAPHIC */

/* Typedefinitionen *****************************************************/

#ifndef GRAPHIC
typedef GEN (PARI_FUNC )(GEN, GEN );
typedef GEN (PARI_FUNC1)(GEN, long);
typedef GEN (PARI_FUNC2)(GEN);
typedef int (PARI_FUNC3)(GEN);
#endif  /* GRAPHIC */

/* Globaler Assoziativer Speicher f"ur die  */
/* Prefixe der Funktion 'genident'          */

extern S_Pointer MSYV_ASS_MEM_GENIDENT;

extern S_Pointer MSYV_userinfo_level;

extern S_Pointer MSYV_EPS;

/**************************************************************************/
/* Deklaration der Systemfunktionen fuer deren Initialisierung.           */
/**************************************************************************/

/* Prototypen zur Datei MSY_sys_func.c **********************************/

S_Pointer MSY_eval_null	( 	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_id ( 	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_contains (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_genident (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_indets (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_help (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_hold (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_last (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_history (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_rtime (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_time (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_append (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_print (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_input (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_textinput (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_text2expr (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_expr2text (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_output_format( S_Pointer        s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_output_type( S_Pointer        s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_level (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_eval (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_map (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_zip (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_select (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_split (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_has (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_sort (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_reset (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_anames (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_stack_info (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec,
				long		 mode );
S_Pointer MSY_eval_float (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_bool (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_system (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_testargs (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_sysname (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_getpid  (    S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_bytes (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_val (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_traperror (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_error_warning_intern (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec,
				bool             error );
S_Pointer MSY_eval_error (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_warning (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_lasterror (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_parser_callback( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_igamma     ( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_isqrt      ( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );

#ifndef MACINTOSH
S_Pointer MSY_eval_register   ( S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
#endif


bool MSY_indets ( S_Pointer s, S_Pointer *assmem, long type,
		     bool enter, S_Pointer call );


/* Prototypen zur Datei MSY_arith_func.c ********************************/

S_Pointer MSY_eval_trans_func (	S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 function );
S_Pointer MSY_eval_arith_func(	S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 function );
#ifndef GRAPHIC
S_Pointer MSY_igcd_ilcm (	S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				bool		 get_gcd,
				S_Pointer	 exec );
S_Pointer MSY_igcd_list (	S_Pointer	 list,
				long		 lower,
				long		 upper );
#endif /* GRAPHIC */

S_Pointer MSY_eval_rdround( 	 S_Pointer	 root,
				 long		 prev_func,
			         long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdint2float(	 S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdabs(	 S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdneg(	 S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdadd(	 S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdsub(	 S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdmul(	 S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rddiv(	 S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdfloat2text( S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdtext2float( S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdisfinite(   S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_eval_rdgetsign(    S_Pointer	 root,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MSY_make_rdinfinity(   long sign );

S_Pointer MSY_eval_int2text(	S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_text2int(	S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_igcd (		S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_ilcm (		S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_igcdex (		S_Pointer	 root,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_sign (		S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_max (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_min (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_powermod (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_ifactor (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_ithprime (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_phi (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_primedivisors( S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_numdivisors (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_pref        (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_sysorder    (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_length      (S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSY_eval_protected   (S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_userinfo(    S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_userinfo_level(S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );
S_Pointer MSY_eval_parser_config(S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );

S_Pointer MSY_eval_lllint      (S_Pointer        s,
                                long             prev_func,
                                long             eval_type,
                                S_Pointer        exec );


#ifndef GRAPHIC
GEN MSY_fact	( GEN value );
GEN MSY_round	( GEN value );
GEN MSY_trunc	( GEN value );
#endif  /* GRAPHIC */


#endif /*__MSY_sys_func_help__ */
